@@ -155,6 +155,42 @@ class QolsysDB:
     def cursor(self) -> sqlite3.Cursor:
         return self._cursor
 
+    def get_users(self) -> list[dict[str, str]]:
+        self.cursor.execute(f"SELECT * FROM {self.table_user.table} ORDER BY _id")
+        self.db.commit()
+
+        users = []
+        columns = [description[0] for description in self.cursor.description]
+        for row in self.cursor.fetchall():
+            row_dict = dict(zip(columns, row, strict=True))
+            users.append(row_dict)
+
+        return users
+
+    def get_master_slave(self) -> list[dict[str, str]]:
+        self.cursor.execute(f"SELECT * FROM {self.table_master_slave.table}")
+        self.db.commit()
+
+        masterslave = []
+        columns = [description[0] for description in self.cursor.description]
+        for row in self.cursor.fetchall():
+            row_dict = dict(zip(columns, row, strict=True))
+            masterslave.append(row_dict)
+
+        return masterslave
+
+    def get_iqremote_settings(self) -> list[dict[str, str]]:
+        self.cursor.execute(f"SELECT * FROM {self.table_iqremotesettings.table}")
+        self.db.commit()
+
+        iqremote_settings = []
+        columns = [description[0] for description in self.cursor.description]
+        for row in self.cursor.fetchall():
+            row_dict = dict(zip(columns, row, strict=True))
+            iqremote_settings.append(row_dict)
+
+        return iqremote_settings
+
     def get_scenes(self) -> list[dict[str, str]]:
         self.cursor.execute(f"SELECT * FROM {self.table_scene.table} ORDER BY scene_id")
         self.db.commit()
@@ -179,6 +215,18 @@ class QolsysDB:
 
         return partitions
 
+    def get_adc_devices(self) -> list[dict[str, str]]:
+        self.cursor.execute(f"SELECT * FROM {self.table_virtual_device.table} ORDER BY device_id")
+        self.db.commit()
+
+        devices = []
+        columns = [description[0] for description in self.cursor.description]
+        for row in self.cursor.fetchall():
+            row_dict = dict(zip(columns, row, strict=True))
+            devices.append(row_dict)
+
+        return devices
+
     def get_zwave_devices(self) -> list[dict[str, str]]:
         self.cursor.execute(f"SELECT * FROM {self.table_zwave_node.table} ORDER BY node_id")
         self.db.commit()
@@ -191,6 +239,18 @@ class QolsysDB:
 
         return devices
 
+    def get_zwave_other_devices(self) -> list[dict[str, str]]:
+        self.cursor.execute(f"SELECT * FROM {self.table_zwave_other.table} ORDER BY node_id")
+        self.db.commit()
+
+        devices = []
+        columns = [description[0] for description in self.cursor.description]
+        for row in self.cursor.fetchall():
+            row_dict = dict(zip(columns, row, strict=True))
+            devices.append(row_dict)
+
+        return devices
+
     def get_locks(self) -> list[dict[str, str]]:
         self.cursor.execute(f"SELECT * FROM {self.table_doorlock.table} ORDER BY node_id")
         self.db.commit()
