@@ -9,6 +9,11 @@ class QolsysError(Exception):
         super().__init__(*args, **kwargs)
 
 
+class QolsysUserCodeError(QolsysError):
+    def __init__(self) -> None:
+        super().__init__("QolsysUserCodeError")
+
+
 class QolsysSslError(QolsysError):
     def __init__(self) -> None:
         super().__init__("QolsysSslError")
