@@ -51,14 +51,6 @@ class QolsysThermostat(QolsysZWaveDevice):
         self._thermostat_operating_state: str = thermostat_dict.get("operating_state", "")
         self._thermostat_setpoint_capabilites = thermostat_dict.get("setpoint_capabilites", "")
 
-        LOGGER.debug("Thermostat%s", self._thermostat_node_id)
-        LOGGER.debug("Thermostat Supported Mode: %s", self.available_thermostat_mode())
-        LOGGER.debug("Thermostat Supported Fan Mode: %s", self.available_thermostat_fan_mode())
-        LOGGER.debug("Thermostat Supported Set Point Mode: %s", self.available_thermostat_set_point_mode())
-        LOGGER.debug("Thermostat Operating State: %s", self._thermostat_operating_state)
-        LOGGER.debug("Thermostat Configuration Parameter: %s", self._thermostat_configuration_parameter)
-        LOGGER.debug("Thermostat Setpoint Capabilites: %s", self._thermostat_setpoint_capabilites)
-
     # -----------------------------
     # properties + setters
     # -----------------------------
@@ -198,9 +190,10 @@ class QolsysThermostat(QolsysZWaveDevice):
 
     @thermostat_mode.setter
     def thermostat_mode(self, value: str) -> None:
-        if self._thermostat_mode != value:
-            LOGGER.debug("Thermostat%s (%s) - mode: %s", self.thermostat_node_id, self.thermostat_name, value)
-            self._thermostat_mode = value
+        new_value = value.strip("[]")
+        if self._thermostat_mode != new_value:
+            LOGGER.debug("Thermostat%s (%s) - mode: %s", self.thermostat_node_id, self.thermostat_name, new_value)
+            self._thermostat_mode = new_value
             self.notify()
 
     @property
@@ -233,9 +226,10 @@ class QolsysThermostat(QolsysZWaveDevice):
 
     @thermostat_fan_mode.setter
     def thermostat_fan_mode(self, value: str) -> None:
-        if self._thermostat_fan_mode != value:
-            LOGGER.debug("Thermostat%s (%s) - fan_mode: %s", self.thermostat_node_id, self.thermostat_name, value)
-            self._thermostat_fan_mode = value
+        new_value = value.strip("[]")
+        if self._thermostat_fan_mode != new_value:
+            LOGGER.debug("Thermostat%s (%s) - fan_mode: %s", self.thermostat_node_id, self.thermostat_name, new_value)
+            self._thermostat_fan_mode = new_value
             self.notify()
 
     @property
